From: Eric Rossman <edrossma@us.ibm.com>

z90crypt device driver changes:
 - Correct the condition for which the reader task is scheduled to run.

Signed-off-by: Martin Schwidefsky <schwidefsky@de.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/s390/crypto/z90main.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff -puN drivers/s390/crypto/z90main.c~s390-z90crypt-reader-task-rescheduling drivers/s390/crypto/z90main.c
--- 25/drivers/s390/crypto/z90main.c~s390-z90crypt-reader-task-rescheduling	2005-03-07 20:41:33.000000000 -0800
+++ 25-akpm/drivers/s390/crypto/z90main.c	2005-03-07 20:41:33.000000000 -0800
@@ -2657,8 +2657,8 @@ z90crypt_reader_task(unsigned long ptr)
 
 	/**
 	 * we use workavail = 2 to ensure 2 passes with nothing dequeued before
 	 * exiting the loop. If pendingq_count == 0 after the loop, there is no
 	 * work remaining on the queues.
 	 */
 	resp_addr = 0;
 	workavail = 2;
@@ -2697,7 +2697,7 @@ z90crypt_reader_task(unsigned long ptr)
 		spin_unlock_irq(&queuespinlock);
 	}
 
-	if (pendingq_count)
+	if (pendingq_count + requestq_count)
 		z90crypt_schedule_reader_timer();
 }
 
@@ -2657,8 +2657,8 @@ z90crypt_reader_task(unsigned long ptr)
 	/**
 	 * we use workavail = 2 to ensure 2 passes with nothing dequeued before
-	 * exiting the loop. If pendingq_count == 0 after the loop, there is no
-	 * work remaining on the queues.
+	 * exiting the loop. If (pendingq_count+requestq_count) == 0 after the
+	 * loop, there is no work remaining on the queues.
 	 */
 	resp_addr = 0;
_